@@ -31,13 +31,32 @@ from extools.env import execution_context, EXEC_VI, EXEC_PS
 
 from remote_actions import get_logger, get_log_path, _alert, _error
 from remote_actions.pollers.errors import (
-        PollerError, 
+        PollerError,
         PollerStartupError, )
 from remote_actions.pollers.adobe_sign import AdobeSignPoller
 from remote_actions.pollers.fleeting_forms import FleetingFormPoller
 
 # Version information for debugging
-VERSION = '6.0.12'
+VERSION = '6.0.13'
+DEFAULT_HANDLER_NAME = 'workflow_approval'
+DEFAULT_HANDLER_CLASSPATH = 'remote_actions.handlers.workflow_approval.WorkflowApprovalFormHandler'
+HANDLER_VIEW_NAME = "REMOTEACTION.VIRAHNDL"
+
+def get_or_create_default_handler():
+    virahndl = openView(HANDLER_VIEW_NAME)
+    if not virahndl:
+        raise RuntimeError("Failed to open the Remote Action Handlers "
+                           "table (VIRAHNDL).")
+    try:
+        virahndl.put("TYPE", DEFAULT_HANDLER_NAME)
+        if virahndl.read() != 0:
+            virahndl.recordGenerate()
+            virahndl.put("TYPE", DEFAULT_HANDLER_NAME)
+            virahndl.put("CLASSPATH", DEFAULT_HANDLER_CLASSPATH)
+            if virahndl.insert() != 0:
+                raise RuntimeError("Failed to install default handler.")
+    finally:
+        virahndl.close()
 
 def main(*args, **kwargs):
     """Entry point for execution - perform a poll."""
@@ -52,6 +71,13 @@ def main(*args, **kwargs):
     logger.info("[start] - version {}, org {}, user {}, program {}.".format(
             VERSION, org, user, program))
 
+    try:
+        get_or_create_default_handler()
+    except RuntimeError as e:
+        logger.error("failed to setup default handler: {}".format(e))
+        _alert("Default handler is not setup: {}".format(e))
+        return
+
     # Create a new poller for this organization and poll.
     successes, errors = [], []
 
